### MMGen version 0.9.5 Release Notes

#### New features:

  - Altcoin framework + full Litecoin support [(commit)](https://github.com/mmgen/mmgen/commit/35d10911596c76227b8cd6318681c6ac9dc02a42)
  - Offline transaction autosigning [(commit)](https://github.com/mmgen/mmgen/commit/8fb3efd99cc2f62e7f12f0e1f9893dd287064035) [(VIDEO)](https://github.com/mmgen/mmgen/releases/tag/autosign)

